@@ -91,7 +91,7 @@ merge.zoo <- function(..., all = TRUE, fill = NA, suffixes = NULL, check.names =
     parent <- parent.frame()
 
     is.plain <- function(x) 
-	all(class(x) %in% c("array", "integer", "numeric", "factor", "matrix", "logical"))
+	all(class(x) %in% c("array", "integer", "numeric", "factor", "matrix", "logical", "character"))
 
     is.scalar <- function(x) is.plain(x) && length(x) == 1
 
